/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

interface nsIVariant;

[scriptable, builtinclass, uuid(f57f7c46-d420-4f32-a61b-0eb585d30ee1)]
interface nsIDOMDOMTransactionEvent : nsIDOMEvent
{
  readonly attribute nsIVariant transactions;

  void initDOMTransactionEvent(in DOMString typeArg,
                               in boolean canBubbleArg,
                               in boolean canCancelArg,
                               in nsIVariant transactions);
};

dictionary DOMTransactionEventInit : EventInit
{
  nsIVariant transactions;
};

