/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIDOMElement.idl"

[scriptable, uuid(5ef62896-0c0a-41f1-bb3c-44a60f5dfdab)]
interface nsITreeContentView : nsISupports
{
  /**
   * Retrieve the content item associated with the specified index.
   */
  nsIDOMElement getItemAtIndex(in long index);

  /**
   * Retrieve the index associated with the specified content item.
   */
  long getIndexOfItem(in nsIDOMElement item);
};
